Learn R Programming

survAUC (version 1.0-0)

AUC.cd: AUC estimation proposed by Chambless and Diao

Description

Chambless and Diao's estimator of cumulative/dynamic AUC for right-censored time-to-event data

Usage

AUC.cd(Surv.rsp, Surv.rsp.new = NULL, lp, lpnew, times)

Arguments

Surv.rsp
A Surv(.,.) object containing to the outcome of the training data.
Surv.rsp.new
A Surv(.,.) object containing the outcome of the test data.
lp
The vector of linear predictors estimated from the training data.
lpnew
The vector of linear predictors obtained from the test data.
times
A vector of time points at which to compute the AUC.

References

Chambless, L. E. and G. Diao (2006). Estimation of time-dependent area under the ROC curve for long-term risk prediction. Statistics in Medicine 25, 3474--3486.

See Also

AUC.uno, AUC.sh, AUC.hc, IntAUC

Examples

Run this code
TR <- ovarian[1:16,]
TE <- ovarian[17:26,]
train.fit  <- coxph(Surv(futime, fustat) ~ age,
                    x=TRUE, y=TRUE, method="breslow", data=TR)

lp <- predict(train.fit)
lpnew <- predict(train.fit, newdata=TE)
Surv.rsp <- Surv(TR$futime, TR$fustat)
Surv.rsp.new <- Surv(TE$futime, TE$fustat)
times <- seq(10, 1000, 10)                  

AUC_CD <- AUC.cd(Surv.rsp, Surv.rsp.new, lp, lpnew, times)

Run the code above in your browser using DataLab