Learn R Programming

survAUC (version 1.0-1)

AUC.hc: AUC estimation proposed by Hung and Chiang

Description

Hung and Chiang's estimator of cumulative/dynamic AUC for right-censored time-to-event data

Usage

AUC.hc(Surv.rsp, Surv.rsp.new, lpnew, times)

Arguments

Surv.rsp
A Surv(.,.) object containing to the outcome of the training data.
Surv.rsp.new
A Surv(.,.) object containing the outcome of the test data.
lpnew
The vector of linear predictors obtained from the test data.
times
A vector of time points at which to compute the AUC.

References

Hung, H. and C.-T. Chiang (2010). Estimation methods for time-dependent AUC models with survival data. Canadian Journal of Statistics 38, 8--26.

See Also

AUC.uno, AUC.sh, AUC.cd, IntAUC

Examples

Run this code
TR <- ovarian[1:16,]
TE <- ovarian[17:26,]
train.fit  <- coxph(Surv(futime, fustat) ~ age,
                    x=TRUE, y=TRUE, method="breslow", data=TR)

lpnew <- predict(train.fit, newdata=TE)
Surv.rsp <- Surv(TR$futime, TR$fustat)
Surv.rsp.new <- Surv(TE$futime, TE$fustat)
times <- seq(10, 1000, 10)                  

AUC_hc <- AUC.hc(Surv.rsp, Surv.rsp.new, lpnew, times)
AUC_hc

Run the code above in your browser using DataLab