Learn R Programming

survAUC (version 1.0-0)

AUC.sh: AUC estimation proposed by Shong and Zhou

Description

Song and Zhou's estimators of AUC for right-censored time-to-event data

Usage

AUC.sh(Surv.rsp, Surv.rsp.new=NULL, lp, lpnew, times, 
		type="incident", savesensspec=FALSE)
sens.sh(Surv.rsp, lp, lpnew, times, type="incident")
spec.sh(Surv.rsp, lp, lpnew, times)

Arguments

Surv.rsp
A Surv(.,.) object containing to the outcome of the training data.
Surv.rsp.new
A Surv(.,.) object containing the outcome of the test data.
lp
The vector of linear predictors estimated from the training data.
lpnew
The vector of linear predictors obtained from the test data.
times
A vector of time points at which to compute the AUC.
type
A string defining the type of true positive rate (TPR): "incident" refers to incident TPR , "cumulative" refers to cumulative TPR.
savesensspec
A logical specifying whether sensitivities and specificities should be saved.

References

Song, X. and X.-H. Zhou (2008). A semiparametric approach for the covariate specific ROC curve with survival outcome. Statistica Sinica 18, 947--965.

See Also

AUC.uno, AUC.cd, AUC.hc, GHCI, IntAUC

Examples

Run this code
TR <- ovarian[1:16,]
TE <- ovarian[17:26,]
train.fit  <- coxph(Surv(futime, fustat) ~ age,
                    x=TRUE, y=TRUE, method="breslow", data=TR)

lp <- predict(train.fit)
lpnew <- predict(train.fit, newdata=TE)
Surv.rsp <- Surv(TR$futime, TR$fustat)
Surv.rsp.new <- Surv(TE$futime, TE$fustat)
times <- seq(10, 1000, 10)                  

AUC_sh <- AUC.sh(Surv.rsp, Surv.rsp.new, lp, lpnew, times)
names(AUC_sh)
AUC_sh$iauc

Run the code above in your browser using DataLab