Learn R Programming

survAUC (version 1.0-1)

AUC.uno: AUC estimation proposed by Uno et al.

Description

Uno's estimator of cumulative/dynamic AUC for right-censored time-to-event data

Usage

AUC.uno(Surv.rsp, Surv.rsp.new, lpnew, times, savesensspec=FALSE)
sens.uno(Surv.rsp, Surv.rsp.new, lpnew, times)
spec.uno(Surv.rsp.new, lpnew, times)

Arguments

Surv.rsp
A Surv(.,.) object containing to the outcome of the training data.
Surv.rsp.new
A Surv(.,.) object containing the outcome of the test data.
lpnew
The vector of linear predictors obtained from the test data.
times
A vector of time points at which to compute the AUC.
savesensspec
A logical specifying whether sensitivities and specificities should be saved.

References

Uno, H., T. Cai, L. Tian, and L. J. Wei (2007). Evaluating prediction rules for t-year survivors with censored regression models. Journal of the American Statistical Association 102, 527--537.

See Also

AUC.cd, AUC.sh, AUC.hc, IntAUC

Examples

Run this code
TR <- ovarian[1:16,]
TE <- ovarian[17:26,]
train.fit  <- coxph(Surv(futime, fustat) ~ age,
                    x=TRUE, y=TRUE, method="breslow", data=TR)

lpnew <- predict(train.fit, newdata=TE)
Surv.rsp <- Surv(TR$futime, TR$fustat)
Surv.rsp.new <- Surv(TE$futime, TE$fustat)
times <- seq(10, 1000, 10)                  

AUC_Uno <- AUC.uno(Surv.rsp, Surv.rsp.new, lpnew, times)
names(AUC_Uno)
AUC_Uno$iauc

Run the code above in your browser using DataLab