Learn R Programming

survAUC (version 1.0-0)

OXS: R2-type Coefficients for Time-to-event Data

Description

R2-type Coefficients for Time-to-event Data

Usage

OXS(Surv.rsp, lp, lp0)
Nagelk(Surv.rsp, lp, lp0)
XO(Surv.rsp, lp, lp0)

Arguments

Surv.rsp
A Surv(.,.) object containing to the outcome of the test data.
lp
The vector of linear predictors.
lp0
The vector of linear predictors obtained from the null model.

References

Nagelkerke, N. J. D. (1991). A note on a general definition of the coefficient of determination. Biometrika 78, 691--692. O'Quigley, J., R. Xu, and J. Stare (2005). Explained randomness in proportional hazards models. Statistics in Medicine 24, 479--489. Xu, R. and J. O'Quigley (1999). A measure of dependence for proportional hazards models. Journal of Nonparametric Statistics 12, 83--107.

See Also

predErr, schemper, GHCI

Examples

Run this code
TR <- ovarian[1:16,]
TE <- ovarian[17:26,]
train.fit  <- coxph(Surv(futime, fustat) ~ age,
                    x=TRUE, y=TRUE, method="breslow", data=TR)

model0 <- coxph(Surv(futime, fustat)~1, data=TR)
model1 <- coxph(Surv(futime, fustat)~age, data=TR)
f0 <- rep(0,nrow(TE))
f1 <- predict(model1, newdata=TE)               
Surv.res <- Surv(TE$futime, TE$fustat)

OXS(Surv.res, f1, f0)
Nagelk(Surv.res, f1, f0)
XO(Surv.res, f1, f0)

Run the code above in your browser using DataLab