Learn R Programming

survAUC (version 1.0-0)

UnoC: C-statistic by Uno et al.

Description

Censoring-adjusted C-statistic by Uno et al.

Usage

UnoC(Surv.rsp, Surv.rsp.new, lpnew, time = NULL)

Arguments

Surv.rsp
A Surv(.,.) object containing to the outcome of the training data.
Surv.rsp.new
A Surv(.,.) object containing the outcome of the test data.
lpnew
The vector of linear predictors obtained from the test data.
time
A positive number restricting the upper limit of the time range under consideration.

References

Uno, H., T. Cai T, M. J. Pencina, R. B. D'Agostino and W. L. Wei (2011). On the C-statistics for evaluating overall adequacy of risk prediction procedures with censored survival data. Statistics in Medicine, to appear.

See Also

GHCI, AUC.sh, IntAUC

Examples

Run this code
TR <- ovarian[1:16,]
TE <- ovarian[17:26,]
train.fit  <- coxph(Surv(futime, fustat) ~ age,
                    x=TRUE, y=TRUE, method="breslow", data=TR)

lpnew <- predict(train.fit, newdata=TE)
Surv.rsp <- Surv(TR$futime, TR$fustat)
Surv.rsp.new <- Surv(TE$futime, TE$fustat)              

Cstat <- UnoC(Surv.rsp, Surv.rsp.new, lpnew)
Cstat

Run the code above in your browser using DataLab