Learn R Programming

survAUC (version 1.0-0)

schemper: Distance-based Estimator of Survival Predictive Accuracy proposed by Schemper and Henderson

Description

Schemper and Henderson's Estimator of the Absolute Deviation between Survival Functions (Prediction Error Curve)

Usage

schemper(train.fit, traindata, newdata)

Arguments

train.fit
A cph object corresponding to the fit of a Cox model.
traindata
A data frame corresponding to the set of training data.
newdata
A data frame corresponding to the set of test data.

Details

This code has been adapted from Lusa et al. (2007).

References

Lusa, L., R. Miceli and L. Mariani (2007). Estimation of predictive accuracy in survival analysis using R and S-PLUS. Computer Methods and Programms in Biomedicine 87, 132--137. Schemper, M. and R. Henderson (2000). Predictive accuracy and explained variation in Cox regression. Biometrics 56, 249--255.

See Also

IntAUC, predErr, OXS