Learn R Programming

survAUC (version 1.0-1)

GHCI: Gonen and Heller's Concordance Index for Cox models

Description

Gonen and Heller's Concordance Index for Cox models

Usage

GHCI(lpnew)

Arguments

lpnew
The vector of linear predictors obtained from the test data.

References

Gonen, M. and G. Heller (2005). Concordance probability and discriminatory power in proportional hazards regression. Biometrika 92, 965--970.

See Also

AUC.sh, IntAUC

Examples

Run this code
TR <- ovarian[1:16,]
TE <- ovarian[17:26,]
train.fit  <- coxph(Surv(futime, fustat) ~ age,
                    x=TRUE, y=TRUE, method="breslow", data=TR)

lpnew <- predict(train.fit, newdata=TE)
                 
GHCI(lpnew)

Run the code above in your browser using DataLab