Rdocumentation
powered by
Learn R Programming
survAUC (version 1.0-0)
IntAUC: IntAUC
Description
Compute summary measures (discrimination indices) from a time-dependent AUC curve
Usage
IntAUC(AUC, times, S, tmax, auc.type="cumulative")
Arguments
AUC
A vector of AUCs.
times
The vector of time points corresponding to
AUC
.
S
A vector of survival probabilities corresponding to
times
.
tmax
A number specifying the upper limit of the time range for which to compute the summary measure.
auc.type
A string defining the type of AUC. 'cumulative' refers to cumulative/dynamic AUC, 'incident' refers to incident/dynamic AUC.
Value
A scalar number corresponding to the summary measure of interest.
See Also
AUC.cd
,
AUC.sh
,
AUC.uno
,
AUC.hc