IntAUC(AUC, times, S, tmax, auc.type="cumulative")AUC.times.tmax]. The values of the AUC curve are
specified via the AUC argument.
In case auc.type = "cumulative" (cumulative/dynamic IAUC), the values of
AUC are weighted by the estimated probability density of
the time-to-event outcome. In case auc.type = "incident" (incident/dynamic
IAUC), the values of AUC are weighted by 2 times the product of the estimated
probability density and the (estimated) survival function of the time-to-event outcome.
The survival function has to be specified via the S argument.
As shown by Heagerty and Zheng (2005), the incident/dynamic version of IAUC
can be interpreted as a global concordance index measuring the probability
that observations with a large predictor value have a shorter survival time than
observations with a small predictor value. The incident/dynamic version of IAUC
has the same interpretation as Harrell's C for survival data.AUC.cd, AUC.sh, AUC.uno,
AUC.hc