Learn R Programming

survAUC (version 1.0-2)

schemper: Distance-based estimator of survival predictive accuracy proposed by Schemper and Henderson

Description

Schemper and Henderson's estimator of the absolute deviation between survival functions

Usage

schemper(train.fit, traindata, newdata)

Arguments

train.fit
A cph object containing the fit of a Cox proportional hazards model.
traindata
A data frame containing the set of training data.
newdata
A data frame containing the set of test data.

Value

  • schemper returns a list with the following components:
  • ModelThe call to cph.
  • DThe estimator of predictive accuracy obtained from the covariate-free null model.
  • DxThe estimator of predictive accuracy obtained from the Cox model.
  • VThe estimator of relative gains in predictive accuracy.
  • MhatThe absolute distance estimator obtained from the Cox model (evaluated at the event times of the test data).
  • Mhat.0The absolute distance estimator obtained from the covariate-free null model (evaluated at the event times of the test data).
  • timepThe event times of the test data.

Details

This code has been adapted from Lusa et al. (2007). Schemper and Henderson's estimator (as implemented by Lusa et al. 2007) assumes that predictions of the time-to-event outcome were obtained from a Cox proportional hazards model. The estimator is valid as long as the Cox model is specified correctly.

Technical details:

  • The Cox model has to be estimated via thecphfunction of theDesignpackage.
  • The survival times and the censoring indicators have to be labelledtimeandstatus, respectively (see example below).
  • In contrast to the other estimators implemented in thesurvAUCpackage,schemperdoes not estimate the survival function of the censoring distribution from the training data but from the test data.
For details on the estimator and its implementation, we refer to Schemper and Henderson (2000) and Lusa et al. (2007).

References

Schemper, M. and R. Henderson (2000). Predictive accuracy and explained variation in Cox regression. Biometrics 56, 249--255. Lusa, L., R. Miceli and L. Mariani (2007). Estimation of predictive accuracy in survival analysis using R and S-PLUS. Computer Methods and Programms in Biomedicine 87, 132--137.

See Also

IntAUC, predErr, OXS

Examples

Run this code
library(Design)
ovarian$time <- ovarian$futime
ovarian$status <- ovarian$fustat
set.seed(2011)
trobs <- sample(1:26,16)
TR <- ovarian[trobs,]
TE <- ovarian[-trobs,]
train.fit  <- cph(Surv(time, status) ~ age,
                  x=TRUE, y=TRUE, method="breslow", data=TR)

schemper(train.fit, TR, TE)

Run the code above in your browser using DataLab